@@ -3,7 +3,7 @@ package Acme::CPANAuthors::Japanese;
 use strict;
 use warnings;
 
-our $VERSION = '0.090101';
+our $VERSION = '0.090911';
 
 use Acme::CPANAuthors::Register (
     AERDAN    => 'Kiyoshi Aman',
@@ -14,6 +14,7 @@ use Acme::CPANAuthors::Register (
     AKOBA     => 'Atsushi Kobayashi',
     AMARISAN  => 'Ryoji Tanida',
     AQL       => 'Tetsuya Toyoda',
+    ARISAWA   => 'Kosuke Arisawa',
     ARUTEIDO  => 'satoshi ishikawa',
     ASAKURA   => 'ASAKURA Takuji',
     ASARIH    => 'Hiro Asari',
@@ -26,6 +27,7 @@ use Acme::CPANAuthors::Register (
     BONAR     => 'Nakano Kyohei',
     BOXPHERE  => 'Satoshi Ohkubo',
     CHIBA     => 'Masahiro Chiba',
+    CLAIRVY   => 'NAGAYA Shinichiro',
     COHTAN    => 'Kota Sakoda',
     DAIBA     => 'DAIBA, Keiichi',
     DANJOU    => 'Nobuo Danjou',
@@ -36,10 +38,12 @@ use Acme::CPANAuthors::Register (
     FUJIMURA  => 'FUJIMURA Yuki',
     FUJIWARA  => 'Fujiwara Shunichiro',
     FUKUDA    => 'Keisuke Fukuda',
+    FUTAYA    => 'Satoshi Futaya',
     GAOU      => 'Kazuharu Arakawa',
     GFUJI     => 'Goro Fuji',
     GUNYA     => 'GUNYARA-KUN',
     HAMANO    => 'Tsukasa Hamano',
+    HAOYAYOI  => 'Soshi Tamura',
     HATA      => 'Masanori HATA',
     HAYASHI   => 'Hiroo HAYASHI',
     HEDWIG    => 'Yusuke Sugiyama',
@@ -48,6 +52,7 @@ use Acme::CPANAuthors::Register (
     HIKARINE  => 'Hajime Kurita',
     HIMAZU    => 'Hideyo Imazu',
     HIO       => 'YAMASHINA Hio',
+    HIRAFOO   => 'Tomoya Hirano',
     HIRATA    => 'HIRATA Yasuyuki',
     HIRATARA  => 'Masahiro Honma',
     HIRO      => 'hiroshi kitano',
@@ -70,6 +75,7 @@ use Acme::CPANAuthors::Register (
     JIRO      => 'Jiro Nishiguchi',
     JKONDO    => 'Junya Kondo',
     JUNICHIRO => 'Junichiro Tobe',
+    KAMIPO    => 'Ryuta Kamizono',
     KAMO      => 'Yoshikazu Kamoshida',
     KAWABATA  => 'KAWABATA Kazumichi',
     KAWASAKI  => 'Kawasaki Yusuke',
@@ -78,6 +84,7 @@ use Acme::CPANAuthors::Register (
     KEISUKE   => 'Keisuke Kuramata',
     KENJIRO   => 'Kenjiro Hirakawa',
     KENTARO   => 'Kentaro Kuribayashi',
+    KIMOTO    => 'Yuki Kimoto',
     KIMURA    => 'Takeshi Kimura',
     KINSAN    => 'Hitoshi Yokozawa',
     KMIYAZAKI => 'Keitaro Miyazaki',
@@ -98,6 +105,7 @@ use Acme::CPANAuthors::Register (
     KWITKNR   => 'KAWAI, Takanori',
     KYANNY    => 'Kensuke Kaneko',
     KYO       => 'Kyo Nagashima',
+    KYORO     => 'Kyosuke INOUE',
     KZFM      => 'Kazufumi Ohkawa',
     KZTOMITA  => 'Kazuyoshi Tomita',
     LUSHE     => 'Masatoshi Mizuno',
@@ -110,6 +118,7 @@ use Acme::CPANAuthors::Register (
     MASAKI    => 'NAKAGAWA Masaki',
     MASANORIH => 'Masanori Hara',
     MASAP     => 'Masahiro Funakoshi',
+    MATSUMOTO => 'syushi matsumoto',
     MATTN     => 'Yasuhiro Matsumoto',
     MIKAGE    => 'SANO Taku',
     MIKI      => 'Takeshi Miki',
@@ -138,6 +147,7 @@ use Acme::CPANAuthors::Register (
     NTSUTSUMI => 'Naoya Tsutsumi',
     NYARLA    => 'Naoki Okamura',
     OINUME    => 'Kazuhiro Oinuma',
+    OISHI     => 'Eisuke Oishi',
     OUEST     => 'Daisuke NISHISAKA',
     OYAMA     => 'Hiroyuki OYAMA',
     OZAWA     => 'OZAWA Sakuro',
@@ -146,6 +156,7 @@ use Acme::CPANAuthors::Register (
     PIA       => 'Michiya Honda',
     QUEEN     => 'Yasuhiro Miyazaki',
     RINTARO   => 'Rintaro Ishizaki',
+    RIYWO     => 'Ryosuke IWANAGA',
     RYOCHIN   => 'Okamoto RYO',
     SADAHIRO  => 'SADAHIRO Tomoyuki',
     SASAO     => 'SASAO Takahiro',
@@ -166,6 +177,7 @@ use Acme::CPANAuthors::Register (
     SHOT      => 'Shota Takayama',
     SKONNO    => 'Satoshi Konno',
     SNGJOKEN  => 'Shingo Kikugawa',
+    SUGMAK    => 'Makoto Sugiyama',
     SUZUKI    => 'Yuji Suzuki',
     TAIY      => 'Taisuke Yamada',
     TAKASHI   => 'Takashi Saeki',
@@ -185,7 +197,9 @@ use Acme::CPANAuthors::Register (
     TAROK     => 'Taro Kawagishi',
     TATENO    => 'Yuichi Tateno',
     TAWAN     => 'Taro Funaki',
+    THORIKAWA => 'Takahiro Horikawa',
     TKURITA   => 'Tetsuro KURITA',
+    TMAESAKA  => 'Toru Maesaka',
     TOCIYUKI  => 'MIZUTANI, Tociyuki',
     TOKUHIROM => 'MATSUNO Tokuhiro',
     TOMITA    => 'Naoki Tomita',
@@ -193,6 +207,7 @@ use Acme::CPANAuthors::Register (
     TOONA     => 'Naoto Ishikawa',
     TOPIA     => 'Tatuya Noda',
     TORU      => 'Toru Hisai',
+    TOSHIFJW  => 'Toshimitsu FUJIWARA',
     TRAVAIL   => 'Tomoyuki SAWA',
     TSUKAMOTO => 'Makio Tsukamoto',
     TSUNODA   => 'TSUNODA Kazuya',
@@ -216,7 +231,9 @@ use Acme::CPANAuthors::Register (
     YSAS      => 'Yasuhiro Sasama',
     YSUZUKI   => 'Yoshihiro SUZUKI',
     YTURTLE   => 'Satoshi Azuma',
+    YUKI      => 'Yuki ANAI',
     YUKINOBU  => 'NAGAYASU Yukinobu',
+    YUKIO     => 'Yukio Suzuki',
     YUPUG     => 'Yu Isobe',
     YUSUKE    => 'Yusuke Shibata',
     YUSUKEBE  => 'Yusuke Wada',
